.r-result-list{list-style:none;margin-top:50px;padding-left:0}.r-result{margin-top:2rem}.r-result-filter{border-bottom:1px solid #cccc;display:flex;gap:20px;padding-bottom:50px}.r-result-filter .r-filter{max-width:200px;width:100%}.r-result-filter .r-filter label{display:block}.r-result-filter .r-filter .r-filter-search{position:relative}.r-result-filter .r-filter .r-filter-search .input-custom-class{border:1px solid #ccc;height:40px;width:100%}.r-result-filter .r-filter .r-filter-search button{background:url(../assets/search.57bdbf5b191499cd77514097d1c4972c.svg) no-repeat;background-position:50%;background-size:80%;border:none;bottom:0;position:absolute;right:10px;top:0;width:20px}.r-list-item-group{margin:15px 0;position:relative}.r-list-item-link{inset:0!important;position:absolute!important}.r-list-item{align-items:stretch;display:flex;height:100%}.r-item-img{flex:0 0 246px;height:149px;width:246px}.r-item-text{margin:20px 30px;position:relative}.r-item-title{display:block}.load-more-link{background:transparent;border:none;display:block;margin:0 auto}.r-content-img{padding-bottom:56.25%}.new-content{margin:0 auto;max-width:700px}.r-filter label{font-size:13px;font-weight:700;margin-bottom:10px;text-transform:uppercase}.select-custom-class div[class*=control]{border-color:#ccc;border-radius:0;height:40px}.r-actu-wrapper{position:relative}.r-actu-wrapper:after{content:url(../assets/oeil-big.f32cd1df1274a9593de0c4bd8e344216.svg);display:block;position:absolute;right:0;top:0;-webkit-transform:translateY(-20%);transform:translateY(-20%);width:495px;z-index:-1}.r-actu-wrapper .r-list-item-group{background:#fff;border:1px solid #d1d1d1;border-radius:15px 15px 15px 0;margin:30px auto;max-width:900px}.r-item-title{font-size:18px;font-weight:700}.r-item-description{color:#444;font-size:16px;margin-top:10px}.r-item-img{border-radius:15px 15px 15px 0}.r-actu-wrapper .r-item-img{flex:0 0 323px;height:220px;width:323px}.r-item-read-more{bottom:0;position:absolute}.r-item-arrow-more{align-self:center;background:#f9b331;background:url(../assets/next-react.17bc43ff4a6a86f4520f5782f6a89a72.svg);background-position:50%;background-repeat:no-repeat;background-size:20px;border-radius:50px;flex:0 0 50px;height:50px;margin-left:auto;margin-right:30px;width:50px}.r-list-item-group:hover .r-item-arrow-more{background:url(../assets/next-react-white.819cb069ac8eec300a9db6a7707712d6.svg),#f9b331;background-position:50%;background-repeat:no-repeat;background-size:20px}