.full-width{left:50%;margin-left:-50vw;margin-right:-50vw;position:relative;right:50%;width:100vw}.r-search-highlighter{background:transparent;border-bottom:2px solid #f9b300;font-weight:700;padding:0;position:relative}.r-search-header{border-bottom:1px solid #000}.r-search-header-title{font-size:15px;font-weight:700;text-transform:uppercase}.r-search-header-count{color:gray;font-size:10px;text-transform:uppercase}.r-search-result{margin-top:2rem}.r-search.search-bar-filter{position:relative}.r-search.search-bar-filter input,.r-search.search-bar-filter label{width:100%}.r-search.search-bar-filter input{border:1px solid #ccc;color:#000;font-weight:700;height:50px;line-height:50px;padding:0 25px}.r-search.search-bar-filter input::-webkit-input-placeholder{color:#000;font-size:18px;opacity:1}.r-search.search-bar-filter input:-ms-input-placeholder{color:#000;font-size:18px;opacity:1}.r-search.search-bar-filter input::placeholder{color:#000;font-size:18px;opacity:1}.r-search.search-bar-filter button{background:transparent;border:none;position:absolute;right:0}.r-search-select{border-radius:0;height:50px}.r-search-list{margin-top:20px;max-height:375px;overflow-y:scroll}.r-search-list .r-search-item{border-bottom:1px solid rgba(0,0,0,.25);display:flex;font-size:14px;gap:10px;list-style:none;padding:1rem 0}.r-search-list .r-search-item .r-search-img{background-repeat:no-repeat;background-size:cover;flex-basis:100%;flex-basis:91px;flex-grow:0;flex-shrink:0;height:61px;width:91px}