#contentview-preview .icon-preview:before {
  content: '\e833';
}

.pat-sortable> :hover {
  cursor: move;
  background: #FFF5CD;
  background: #E7E9ED;
}

#plone-contentmenu-factories {
  [class*="contenttype-"] {
    &:before {
      font-family: fontello;
    }
  }

  .contenttype-link::before {
    content: '\e806';
  }

  .contenttype-file::before {
    content: '\e811';
  }

  .contenttype-image::before {
    content: '\e810';
  }

  .contenttype-collection::before {
    content: '\e808';
  }

  .contenttype-imio-smartweb-folder::before {
    content: '\e801';
  }

  .contenttype-imio-smartweb-directoryview::before {
    content: '\e842';
  }

  .contenttype-imio-smartweb-eventsview::before {
    content: '\e809';
  }

  .contenttype-imio-smartweb-newsview::before {
    content: '\e80f';
  }

  .contenttype-imio-smartweb-page::before,
  .contenttype-imio-smartweb-portalpage::before,
  .contenttype-imio-smartweb-procedure::before,
  .contenttype-collective-pivot-family::before {
    content: '\e80e';
  }

  .contenttype-imio-smartweb-blocklink:before,
  .contenttype-imio-smartweb-sectioncollection:before,
  .contenttype-imio-smartweb-sectionevents:before,
  .contenttype-imio-smartweb-sectionmap:before,
  .contenttype-imio-smartweb-sectionnews:before,
  .contenttype-imio-smartweb-sectionvideo:before {
    content: '\e834';
  }

  .contenttype-imio-smartweb-sectioncontact:before {
    content: '\e800';
  }

  .contenttype-imio-smartweb-sectionfiles:before {
    content: '\e811';
  }

  .contenttype-imio-smartweb-sectionhtml:before {
    content: '\e815';
    font-weight: bold;
  }

  .contenttype-imio-smartweb-sectionlinks:before {
    content: '\e806';
  }

  .contenttype-imio-smartweb-sectiontext:before {
    content: '\e816';
  }

  .contenttype-imio-smartweb-sectiongallery:before {
    content: '\e818';
  }

  .contenttype-imio-smartweb-sectionselections:before {
    content: '\e803';
  }
}

.pat-sortable {
  position: relative;
  display: block;

  .sortable-section {
    padding: 0.5rem;
    margin-top: 1rem;
    margin-bottom: 1rem;
    border: 1px solid #dee2e6 !important;
  }
}

.hidden-section-title {
  opacity: 0.3;
}

.section-title {
  display: inline-block;
  vertical-align: middle;
}

.content-section {
  h2 {
    display: inline-block;
  }
}

.show-hide-banner {
  display: inline-block;
  padding: 15px;
  background: #fff;
  border: solid 1px #e6e6e6;
}

.header-section {
  background: #f2f2f2;
  padding: 0 1rem;
  line-height: 1.9;
  margin-top: 1rem !important;
  margin-bottom: 1rem !important;
}

table.table_schedule {
  cursor: default;
}