#contentview-preview .icon-preview:before{content:'\e833'}.pat-sortable>:hover{cursor:move;background:#FFF5CD;background:#E7E9ED}#plone-contentmenu-factories [class*="contenttype-"]:before{font-family:fontello}#plone-contentmenu-factories .contenttype-link::before{content:'\e806'}#plone-contentmenu-factories .contenttype-file::before{content:'\e811'}#plone-contentmenu-factories .contenttype-image::before{content:'\e810'}#plone-contentmenu-factories .contenttype-collection::before{content:'\e808'}#plone-contentmenu-factories .contenttype-imio-smartweb-folder::before{content:'\e801'}#plone-contentmenu-factories .contenttype-imio-smartweb-directoryview::before{content:'\e842'}#plone-contentmenu-factories .contenttype-imio-smartweb-eventsview::before{content:'\e809'}#plone-contentmenu-factories .contenttype-imio-smartweb-newsview::before{content:'\e80f'}#plone-contentmenu-factories .contenttype-imio-smartweb-page::before,#plone-contentmenu-factories .contenttype-imio-smartweb-portalpage::before,#plone-contentmenu-factories .contenttype-imio-smartweb-procedure::before,#plone-contentmenu-factories .contenttype-collective-pivot-family::before{content:'\e80e'}#plone-contentmenu-factories .contenttype-imio-smartweb-blocklink:before,#plone-contentmenu-factories .contenttype-imio-smartweb-sectioncollection:before,#plone-contentmenu-factories .contenttype-imio-smartweb-sectionevents:before,#plone-contentmenu-factories .contenttype-imio-smartweb-sectionmap:before,#plone-contentmenu-factories .contenttype-imio-smartweb-sectionnews:before,#plone-contentmenu-factories .contenttype-imio-smartweb-sectionvideo:before{content:'\e834'}#plone-contentmenu-factories .contenttype-imio-smartweb-sectioncontact:before{content:'\e800'}#plone-contentmenu-factories .contenttype-imio-smartweb-sectionfiles:before{content:'\e811'}#plone-contentmenu-factories .contenttype-imio-smartweb-sectionhtml:before{content:'\e815';font-weight:bold}#plone-contentmenu-factories .contenttype-imio-smartweb-sectionlinks:before{content:'\e806'}#plone-contentmenu-factories .contenttype-imio-smartweb-sectiontext:before{content:'\e816'}#plone-contentmenu-factories .contenttype-imio-smartweb-sectiongallery:before{content:'\e818'}#plone-contentmenu-factories .contenttype-imio-smartweb-sectionselections:before{content:'\e803'}.pat-sortable{position:relative;display:block}.pat-sortable .sortable-section{padding:.5rem;margin-top:1rem;margin-bottom:1rem;border:1px solid #dee2e6 !important}.hidden-section-title{opacity:.3}.section-title{display:inline-block;vertical-align:middle}.content-section h2{display:inline-block}.show-hide-banner{display:inline-block;padding:15px;background:#fff;border:solid 1px #e6e6e6}.header-section{background:#f2f2f2;padding:0 1rem;line-height:1.9;margin-top:1rem !important;margin-bottom:1rem !important}table.table_schedule{cursor:default}/*# sourceMappingURL=smartweb-edit-compiled.css.map */