jQuery(document).ready(function(t){t(".opening_informations").click(function(s){t(this).siblings(".table_schedule").toggle("fast"),t(this).toggle("fast"),s.preventDefault()}),t(".table_schedule").click(function(s){t(this).siblings(".opening_informations").toggle("fast"),t(this).toggle("fast"),s.preventDefault()}),t(".swiper").each(function(s){var e=t(this).attr("data-nb-results-by-batch");new Swiper(t(this)[0],{slidesPerView:1,slidesPerGroup:1,spaceBetween:10,pagination:{el:".swiper-pagination",clickable:!0},navigation:{nextEl:".swiper-button-next",prevEl:".swiper-button-prev"},breakpoints:{320:{slidesPerView:1,slidesPerGroup:1},576:{slidesPerView:1<e?2:1,slidesPerGroup:1<e?2:1},768:{slidesPerView:2<e?2:e,slidesPerGroup:2<e?2:e},992:{slidesPerView:2<e?3:e,slidesPerGroup:2<e?3:e},1200:{slidesPerView:e,slidesPerGroup:e}}})})}),$(document).ready(function(){const e=$("#portal-globalnav-collapse"),t=$("#subsite-navigation");function a(){e.removeClass("activated"),t.removeClass("activated"),$(".show-nav").removeClass("show-nav"),$(".mask-menu").removeClass("in")}$(".close-nav").click(function(){a()}),$(document).mouseup(s=>{e.is(s.target)||0!==e.has(s.target).length||t.is(s.target)||0!==t.has(s.target).length||a()}),$("li.has_subtree > a").click(function(){return 0<$(this).closest(e).length&&(0<!$("#portal-globalnav .show-nav").length&&($(e).toggleClass("activated"),$(".mask-menu").toggleClass("in")),$(this).parent().toggleClass("show-nav"),$(this).parent().find(".show-nav").toggleClass("show-nav"),$(this).parent().siblings(".show-nav").toggleClass("show-nav"),$(this).parent().find(".activated").toggleClass(".activated"),0<!$("#portal-globalnav .show-nav").length&&a()),0<$(this).closest(t).length&&(0<!$("#subsite-navigation .show-nav").length&&$(t).toggleClass("activated"),$(this).parent().toggleClass("show-nav"),$(this).parent().find(".show-nav").toggleClass("show-nav"),$(this).parent().siblings(".show-nav").toggleClass("show-nav"),$(this).parent().find(".activated").toggleClass(".activated"),0<!$("#subsite-navigation .show-nav").length&&a()),!1}),$(".prev-nav").click(function(){$(this).closest(".show-nav").toggleClass("show-nav")})}),define("/Users/laurent/instances/buildout.smartweb/src/imio.smartweb.core/src/imio/smartweb/core/browser/static/view.js",function(){});
//# sourceMappingURL=smartweb-view-compiled.js.map