.r-wrapper{
}
.r-result-list{
  margin-top: 50px;
  padding-left: 0;
  list-style: none;
}
  /* Filters */
  .r-result{
    margin-top: 2rem;
    &-filter{
      display: flex;
      gap: 20px;
      padding-bottom: 50px;
      border-bottom: solid 1px #cccc;
      .r-filter{
        width: 100%;
        max-width: 200px;
        label{
          display: block;
        }
        .r-filter-search{
          position: relative;
          .input-custom-class{
            height: 40px;
            border: solid 1px #ccc;
            width: 100%;
          }
          button{
            background: url(../../assets/search.svg) no-repeat;
            background-position: center;
            background-size: 80%;
            border: none;
            width: 20px;
            position: absolute;
            right: 10px;
            top: 0;
            bottom: 0;
          }
        }

      }
    }
  }
  /* list item */
  .r-list-item-group{
    margin: 15px 0;
    position: relative;
  }
  .r-list-item-link{
    inset: 0px !important;
    position: absolute !important;
  }
  .r-list-item{
    display: flex;
    height: 100%;
    align-items: stretch;
  }
  /* image */
  .r-item-img{
    width: 246px;
    height: 149px;
    flex: 0 0 246px;
  }
    /* text */
.r-item-text{
  margin: 20px 30px;
  position: relative;
}
.r-item-title{
  display: block;
}
  /* load-more-link */
  .load-more-link{
    background: transparent;
    margin: 0 auto;
    border: none;
    display: block;
  }

// content

.r-content-img{
  padding-bottom: 56.25%;
}
.new-content {
  max-width: 700px;
  margin: 0 auto;
}
//// for bla ////
  /* filters */
  .r-filter{
    label{
      text-transform: uppercase;
      font-weight: bold;
      font-size: 13px;
      margin-bottom: 10px;
    }
  }
  .select-custom-class{
    div[class*="control"]{
      border-radius: 0;
      height: 40px;
      border-color: #CCCCCC;
    }
  }
  /* list item */
  .r-actu-wrapper{
    position: relative;
    &:after{
      width: 495px;
      display: block;
      position: absolute;
      content: url(../../assets/oeil-big.svg);
      z-index: -1;
      top: 0;
      right: 0;
      transform: translateY(-20%);
    }
    .r-list-item-group{
      max-width: 900px;
      margin: 30px auto;
      background: #fff;
      border-radius: 15px 15px 15px 0;
      border: 1px solid #D1D1D1;
    }
  }
  /* text */
.r-item-title{
  font-size: 18px;
  font-weight: bold;
}
.r-item-description{
  font-size: 16px;
  color: #444444;
  margin-top: 10px;
}
  /* image */
  .r-item-img{
    border-radius: 15px 15px 15px 0px;
  }
  .r-actu-wrapper{
    .r-item-img{
      width: 323px;
      height: 220px;
      flex: 0 0 323px;
    }
  }
  /* arrow more */
  .r-item-read-more{
    position: absolute;
    bottom: 0;
  }
  .r-item-arrow-more{
    width: 50px;
    height: 50px;
    background: #F9B331;
    border-radius: 50px;
    flex: 0 0 50px;
    margin-left: auto;
    align-self: center;
    margin-right: 30px;
    background: url(../../assets/next-react.svg);
    background-repeat: no-repeat;
    background-size: 20px;
    background-position: center;
  }
  .r-list-item-group{
    &:hover{
    .r-item-arrow-more{
      background: url(../../assets/next-react-white.svg),#F9B331;
      background-repeat: no-repeat;
      background-size: 20px;
      background-position: center;
    }
    }
  }