
  /* Filters */
  .r-result{
    margin-top: 2rem;
    &-filter{
      display: flex;
      gap: 20px;
      padding-bottom: 50px;
      border-bottom: solid 1px #cccc;
      .r-filter{
        width: 100%;
        max-width: 200px;
        label{
          display: block;
        }
        .r-filter-search{
          position: relative;
          .input-custom-class{
            height: 40px;
            border: solid 1px #ccc;
            width: 100%;
          }
          button{
            background: url(../../assets/search.svg) no-repeat;
            background-position: center;
            background-size: 80%;
            border: none;
            width: 20px;
            position: absolute;
            right: 10px;
            top: 0;
            bottom: 0;
          }
        }

      }
    }
  }
//// for bla ////
  /* filters */
  .r-filter{
    label{
      text-transform: uppercase;
      font-weight: bold;
      font-size: 13px;
      margin-bottom: 10px;
    }
  }
  .select-custom-class{
    div[class*="control"]{
      border-radius: 0;
      height: 40px;
      border-color: #CCCCCC;
    }
  }
// content

.r-content-img{
  padding-bottom: 56.25%;
}



































//////

.headerimg{
  margin: 0 auto;
  display: block;
}
.footer{
  background: #000;
  height: 500px;
  width: 100vw;
}
.r-wrapper{
  display: grid;
  grid-template-columns: minmax(20px, 800px) minmax(20px, 100%);
  justify-content: space-between;
  width:     calc(648px + 50vw);
  margin-left: auto;
  gap: 40px;
  overflow: hidden;
  .r-result{
    margin-top: 2rem;
    &-filter{
      display: flex;
      gap: 20px;
      .r-filter{
        width: 100%;
      }
    }
    &-list{
      padding:0;
      .r-list-item-group{
        position: relative;
        list-style: none;
        margin:1rem 0;
        .r-list-item-link{
          inset: 0px !important;
          position: absolute !important;
        }
        .r-list-item{
          display: flex;
          height: 100%;
          .r-item-img{
            width: 246px;
            height: 149px;
            background-size: cover;
          }
          .r-item-text{
            margin-left: 1.5rem;
            flex-grow: 1;
            a{
              position: relative;
            }
            .r-item-title{
              font-weight: bold;
              display: block;
            }
            .r-item-categorie{
              display: block;
            }
            .r-item-all{
              display: flex;
              gap: 10px;
              .r-item-adresse{
                width: 36%;
              }
              .r-item-contact{
              }
            }
          }
        }
      }
    }
  }
  .r-map{
    .leaflet-container{

    }
  }
}



// FOR BLA

.r-wrapper{

  .r-result{
    &-filter{

      .r-filter{
      }
    }
    &-list{
      .r-list-item-group{

        .r-list-item-link{

        }
        .r-list-item{

          .r-item-img{
            border-radius: 15px 15px 15px 0px;
          }
          .r-item-text{
            font-size: 13px;
            &:after{
              content: "";
              width: 50px;
              height: 50px;
              background: yellow;
              border-radius: 50px;
            }
            a{
            }
            .r-item-title{
              font-size: 18px;
            }
            .r-item-categorie{
              margin-bottom: 5px;
            }
            .r-item-all{
              color: #727272;

              a{
                color: #000;
              }
              .r-item-adresse{
                .itineraty{
                  margin-top: 5px;
                  &:before{
                    content: "";
                    width: 15px;
                    height: 15px;
                    display: inline-block;
                    background-size: contain;
                    background: url(../../assets/location-bla.svg) no-repeat;
                    vertical-align: middle;
                  }
                }
              }
              .r-item-contact{
                width: 100%;
              }
            }
          }
        }
      }
    }
  }
  .r-map{
    .leaflet-container{

    }
  }
}
